SecureArray

Struct SecureArray 

pub struct SecureArray<T, const LENGTH: usize>
where T: Copy + Zeroize,
{ /* private fields */ }
A data type suitable for storing sensitive information such as passwords and private keys in memory, that implements:

  • Automatic zeroing in Drop
  • Constant time comparison in PartialEq (does not short circuit on the first different character; but terminates instantly if strings have different length)
  • Outputting ***SECRET*** to prevent leaking secrets into logs in fmt::Debug and fmt::Display
  • Automatic mlock to protect against leaking into swap (any unix)
  • Automatic madvise(MADV_NOCORE/MADV_DONTDUMP) to protect against leaking into core dumps (FreeBSD, DragonflyBSD, Linux)

Implementations

Source

impl<T, const LENGTH: usize> SecureArray<T, LENGTH>
where T: Copy + Zeroize,

pub fn new(content: [T; LENGTH]) -> Self

pub fn unsecure(&self) -> &[T]

Borrow the contents of the string.

pub fn unsecure_mut(&mut self) -> &mut [T]

Mutably borrow the contents of the string.

pub fn zero_out(&mut self)

Overwrite the string with zeros. This is automatically called in the destructor.