pub struct SecureBox<T>where
T: Copy,{ /* private fields */ }Expand description
A data type suitable for storing sensitive information such as passwords and private keys in memory, that implements:
- Automatic zeroing in
Drop - Constant time comparison in
PartialEq(does not short circuit on the first different character; but terminates instantly if strings have different length) - Outputting
***SECRET***to prevent leaking secrets into logs infmt::Debugandfmt::Display - Automatic
mlockto protect against leaking into swap (any unix) - Automatic
madvise(MADV_NOCORE/MADV_DONTDUMP)to protect against leaking into core dumps (FreeBSD, DragonflyBSD, Linux)
Implementations